@@ -27,6 +27,8 @@ Copyright_License {
 class Context;
 class NativeView;
 class Vibrator;
+class BluetoothHelper;
+class UsbSerialHelper;
 class IOIOHelper;
 
 /**
@@ -41,6 +43,8 @@ extern NativeView *native_view;
 extern Vibrator *vibrator;
 extern bool os_haptic_feedback_enabled;
 
+extern BluetoothHelper *bluetooth_helper;
+extern UsbSerialHelper *usb_serial_helper;
 extern IOIOHelper *ioio_helper;
 
 #endif
