@@ -33,7 +33,7 @@ Copyright_License {
 #include <string.h>
 
 static constexpr bool
-IsForbiddenFlarmChar(unsigned char ch)
+IsForbiddenFlarmChar(unsigned char ch) noexcept
 {
   return
     /* don't allow ASCII control characters */
@@ -43,15 +43,19 @@ IsForbiddenFlarmChar(unsigned char ch)
 }
 
 char *
-CopyCleanFlarmString(char *gcc_restrict dest, const char *gcc_restrict src)
+CopyCleanFlarmString(char *gcc_restrict dest, const char *gcc_restrict src,
+                     std::size_t maxBytes) noexcept
 {
-  while (true) {
+  std::size_t i=0;
+  while (i < maxBytes) {
     char ch = *src++;
     if (ch == 0)
       break;
 
-    if (!IsForbiddenFlarmChar(ch))
+    if (!IsForbiddenFlarmChar(ch)) {
       *dest++ = ch;
+      i++;
+    }
   }
 
   *dest = 0;
