@@ -25,6 +25,7 @@ Copyright_License {
 #include "time/BrokenDateTime.hpp"
 #include "Math/Angle.hpp"
 #include "Engine/Waypoint/Waypoint.hpp"
+#include "time/Calendar.hxx"
 
 #ifdef _UNICODE
 #include <stringapiset.h>
@@ -33,11 +34,6 @@ Copyright_License {
 #define IMI_SECONDS_IN_MINUTE       (60)
 #define IMI_SECONDS_IN_HOUR      (60*60)
 #define IMI_SECONDS_IN_DAY    (24*60*60)
-#define IMI_ISLEAP(y) ((y & 3) == 0) //simple version valid for years 2000-2099
-#define IMI_DAYS_IN_YEAR(year) (IMI_ISLEAP(year) ? 366 : 365)
-
-static constexpr IMI::IMIBYTE IMI_DAYS_IN_MONTH[12] =
-  { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 
 void
 IMI::ConvertToChar(const TCHAR* unicode, char* ascii, int outSize)
@@ -63,50 +59,38 @@ IMI::ConvertToDateTime(IMI::IMIDATETIMESEC in)
 {
   BrokenDateTime out;
 
-  if (in >= IMI_SECONDS_IN_DAY) {
-    // find year
-    for (out.year = 0; out.year <= 99; out.year++) {
-      unsigned secondsinyear = IMI_DAYS_IN_YEAR(out.year) * IMI_SECONDS_IN_DAY;
-      if (in < secondsinyear)
-        break;
+  // find year
+  for (out.year = 2000; out.year <= 2099; ++out.year) {
+    unsigned secondsinyear = DaysInYear(out.year) * IMI_SECONDS_IN_DAY;
+    if (in < secondsinyear)
+      break;
 
-      in -= secondsinyear;
-    }
-
-    // find month
-    for (out.month = 0; out.month < 12; out.month++) {
-      unsigned secondsinmonth = IMI_DAYS_IN_MONTH[out.month]
-          * IMI_SECONDS_IN_DAY;
-      if (out.month == 1 && IMI_ISLEAP(out.year))
-        secondsinmonth += IMI_SECONDS_IN_DAY;
-
-      if (in < secondsinmonth)
-        break;
-      in -= secondsinmonth;
-    }
-
-    // calculate day
-    out.day = (uint8_t)(in / IMI_SECONDS_IN_DAY);
-    in -= (out.day) * IMI_SECONDS_IN_DAY;
-  } else {
-    out.year = 0;
-    out.month = 0;
-    out.day = 0;
+    in -= secondsinyear;
   }
 
+  // find month
+  for (out.month = 1; out.month <= 12; ++out.month) {
+    unsigned secondsinmonth = DaysInMonth(out.month, out.year)
+      * IMI_SECONDS_IN_DAY;
+
+    if (in < secondsinmonth)
+      break;
+    in -= secondsinmonth;
+  }
+
+  // calculate day
+  out.day = (uint8_t)(1 + in / IMI_SECONDS_IN_DAY);
+  in %= IMI_SECONDS_IN_DAY;
+
   // hour, minutes and seconds
   out.hour = (uint8_t)(in / IMI_SECONDS_IN_HOUR);
-  in -= (out.hour) * IMI_SECONDS_IN_HOUR;
+  in %= IMI_SECONDS_IN_HOUR;
 
   out.minute = (uint8_t)(in / IMI_SECONDS_IN_MINUTE);
-  in -= (out.minute) * IMI_SECONDS_IN_MINUTE;
+  in %= IMI_SECONDS_IN_MINUTE;
 
   out.second = (uint8_t)in;
 
-  out.year += 2000;
-  out.month++;
-  out.day++;
-
   return out;
 }
 
