@@ -28,7 +28,6 @@ Copyright_License {
 #include "UIGlobals.hpp"
 #include "Look/DialogLook.hpp"
 #include "Form/Panel.hpp"
-#include "Form/List.hpp"
 #include "Form/Draw.hpp"
 #include "Form/Button.hpp"
 #include "Renderer/SymbolButtonRenderer.hpp"
@@ -42,6 +41,7 @@ Copyright_License {
 #include "Screen/Layout.hpp"
 #include "ui/event/KeyCode.hpp"
 #include "ui/control/LargeTextWindow.hpp"
+#include "ui/control/List.hpp"
 #include "MainWindow.hpp"
 #include "Interface.hpp"
 #include "Components.hpp"
