@@ -64,7 +64,7 @@ struct SpeedState
    */
   double true_airspeed;
 
-  void Reset() noexcept {
+  constexpr void Reset() noexcept {
     ground_speed = true_airspeed = 0;
   }
 };
@@ -87,7 +87,11 @@ struct AltitudeState
   /** Altitude over terrain */
   double altitude_agl;
 
-  void Reset() noexcept;
+  constexpr void Reset() noexcept {
+    altitude = 0;
+    working_band_fraction = 0;
+    altitude_agl = 0;
+  }
 };
 
 /**
@@ -107,7 +111,7 @@ struct VarioState
    */
   double netto_vario;
 
-  void Reset() noexcept {
+  constexpr void Reset() noexcept {
     vario = netto_vario = 0;
   }
 };
@@ -160,7 +164,7 @@ struct AircraftState:
     return time.IsDefined();
   }
 
-  void ResetTime() noexcept {
+  constexpr void ResetTime() noexcept {
     time = TimeStamp::Undefined();
   }
 
@@ -174,7 +178,18 @@ struct AircraftState:
   [[gnu::pure]]
   AircraftState GetPredictedState(FloatDuration in_time) const noexcept;
 
-  void Reset() noexcept;
+  constexpr void Reset() noexcept {
+    AltitudeState::Reset();
+    SpeedState::Reset();
+    VarioState::Reset();
+
+    ResetTime();
+    location.SetInvalid();
+    track = Angle::Zero();
+    g_load = 1;
+    wind = SpeedVector::Zero();
+    flying = false;
+  }
 };
 
 static_assert(std::is_trivial<AircraftState>::value, "type is not trivial");
