@@ -25,14 +25,15 @@
 
 #include "Geo/Flat/FlatGeoPoint.hpp"
 #include "Geo/Flat/FlatBoundingBox.hpp"
-#include "util/ConstBuffer.hxx"
 
 #include <vector>
+#include <span>
+
+class FlatTriangleFanVisitor;
 
 class FlatTriangleFan {
-  typedef std::vector<FlatGeoPoint> VertexVector;
+  using VertexVector = std::vector<FlatGeoPoint>;
 
-protected:
   VertexVector vs;
   FlatBoundingBox bounding_box;
   int height;
@@ -40,7 +41,7 @@ protected:
 public:
   friend class PrintHelper;
 
-  void CalcBoundingBox() noexcept;
+  const FlatBoundingBox &CalcBoundingBox() noexcept;
 
   /**
    * Add the origin to an empty
@@ -69,11 +70,20 @@ public:
     vs.clear();
   }
 
+  std::span<const FlatGeoPoint> GetVertices() const noexcept {
+    return vs;
+  }
+
   [[gnu::pure]]
   bool IsEmpty() const noexcept {
     return vs.empty();
   }
 
+  [[gnu::pure]]
+  bool IsOnlyOrigin() const noexcept {
+    return vs.size() == 1;
+  }
+
   AFlatGeoPoint GetOrigin() const noexcept {
     return AFlatGeoPoint(vs.front(), height);
   }
@@ -85,18 +95,26 @@ public:
    * not part of the hull
    */
   [[gnu::pure]]
-  ConstBuffer<FlatGeoPoint> GetHull(bool closed) const noexcept {
-    ConstBuffer<FlatGeoPoint> hull(&vs.front(), vs.size());
+  std::span<const FlatGeoPoint> GetHull(bool closed) const noexcept {
+    std::span<const FlatGeoPoint> hull{vs};
     if (closed)
       /* omit the origin, because it's not part of the hull in a
          closed shape */
-      hull.pop_front();
+      hull = hull.subspan(1);
     return hull;
   }
 
   int GetHeight() const noexcept {
     return height;
   }
+
+  void SetHeight(int _height) noexcept {
+    height = _height;
+  }
+
+  void AcceptInRange(const FlatBoundingBox &bb,
+                     FlatTriangleFanVisitor &visitor,
+                     bool closed) const noexcept;
 };
 
 #endif
