@@ -70,7 +70,13 @@ Waypoints::WaypointNameTree::Add(WaypointPtr wp)
 {
   AllocatedArray<TCHAR> buffer(wp->name.length() + 1);
   NormalizeSearchString(buffer.data(), wp->name.c_str());
-  RadixTree<WaypointPtr>::Add(buffer.data(), std::move(wp));
+  RadixTree<WaypointPtr>::Add(buffer.data(), wp);
+
+  if (!wp->shortname.empty()) {
+    buffer.GrowDiscard(wp->shortname.length() + 1);
+    NormalizeSearchString(buffer.data(), wp->shortname.c_str());
+    RadixTree<WaypointPtr>::Add(buffer.data(), std::move(wp));
+  }
 }
 
 inline void
@@ -79,6 +85,12 @@ Waypoints::WaypointNameTree::Remove(const WaypointPtr &wp)
   AllocatedArray<TCHAR> buffer(wp->name.length() + 1);
   NormalizeSearchString(buffer.data(), wp->name.c_str());
   RadixTree<WaypointPtr>::Remove(buffer.data(), wp);
+
+  if (!wp->shortname.empty()) {
+    buffer.GrowDiscard(wp->shortname.length() + 1);
+    NormalizeSearchString(buffer.data(), wp->shortname.c_str());
+    RadixTree<WaypointPtr>::Remove(buffer.data(), wp);
+  }
 }
 
 Waypoints::Waypoints()
