@@ -50,13 +50,13 @@ struct TrafficList {
   /** Flarm traffic information */
   TrivialArray<FlarmTraffic, MAX_COUNT> list;
 
-  void Clear() {
+  constexpr void Clear() noexcept {
     modified.Clear();
     new_traffic.Clear();
     list.clear();
   }
 
-  bool IsEmpty() const {
+  constexpr bool IsEmpty() const noexcept {
     return list.empty();
   }
 
@@ -64,7 +64,9 @@ struct TrafficList {
    * Adds data from the specified object, unless already present in
    * this one.
    */
-  void Complement(const TrafficList &add) {
+  constexpr void Complement(const TrafficList &add) noexcept {
+    if (IsEmpty() && !add.IsEmpty())
+      *this = add;
     // Add unique traffic from 'add' list
     for (auto &traffic : add.list) {
       if (FindTraffic(traffic.id) == nullptr) {
@@ -76,7 +78,7 @@ struct TrafficList {
     }
   }
 
-  void Expire(TimeStamp clock) noexcept {
+  constexpr void Expire(TimeStamp clock) noexcept {
     modified.Expire(clock, std::chrono::minutes(5));
     new_traffic.Expire(clock, std::chrono::minutes(1));
 
@@ -85,7 +87,7 @@ struct TrafficList {
         list.quick_remove(i);
   }
 
-  unsigned GetActiveTrafficCount() const {
+  constexpr unsigned GetActiveTrafficCount() const noexcept {
     return list.size();
   }
 
@@ -95,7 +97,7 @@ struct TrafficList {
    * @param id FLARM id
    * @return the FLARM_TRAFFIC pointer, NULL if not found
    */
-  FlarmTraffic *FindTraffic(FlarmId id) {
+  constexpr FlarmTraffic *FindTraffic(FlarmId id) noexcept {
     for (auto &traffic : list)
       if (traffic.id == id)
         return &traffic;
@@ -109,7 +111,7 @@ struct TrafficList {
    * @param id FLARM id
    * @return the FLARM_TRAFFIC pointer, NULL if not found
    */
-  const FlarmTraffic *FindTraffic(FlarmId id) const {
+  constexpr const FlarmTraffic *FindTraffic(FlarmId id) const noexcept {
     for (const auto &traffic : list)
       if (traffic.id == id)
         return &traffic;
@@ -123,7 +125,7 @@ struct TrafficList {
    * @param name the name or call sign
    * @return the FLARM_TRAFFIC pointer, NULL if not found
    */
-  FlarmTraffic *FindTraffic(const TCHAR *name) {
+  constexpr FlarmTraffic *FindTraffic(const TCHAR *name) noexcept {
     for (auto &traffic : list)
       if (traffic.name.equals(name))
         return &traffic;
@@ -137,7 +139,7 @@ struct TrafficList {
    * @param name the name or call sign
    * @return the FLARM_TRAFFIC pointer, NULL if not found
    */
-  const FlarmTraffic *FindTraffic(const TCHAR *name) const {
+  constexpr const FlarmTraffic *FindTraffic(const TCHAR *name) const noexcept {
     for (const auto &traffic : list)
       if (traffic.name.equals(name))
         return &traffic;
@@ -150,7 +152,7 @@ struct TrafficList {
    *
    * @return the FLARM_TRAFFIC pointer, NULL if the array is full
    */
-  FlarmTraffic *AllocateTraffic() {
+  constexpr FlarmTraffic *AllocateTraffic() noexcept {
     return list.full()
       ? NULL
       : &list.append();
@@ -159,7 +161,7 @@ struct TrafficList {
   /**
    * Search for the previous traffic in the ordered list.
    */
-  const FlarmTraffic *PreviousTraffic(const FlarmTraffic *t) const {
+  constexpr const FlarmTraffic *PreviousTraffic(const FlarmTraffic *t) const noexcept {
     return t > list.begin()
       ? t - 1
       : NULL;
@@ -168,7 +170,7 @@ struct TrafficList {
   /**
    * Search for the next traffic in the ordered list.
    */
-  const FlarmTraffic *NextTraffic(const FlarmTraffic *t) const {
+  constexpr const FlarmTraffic *NextTraffic(const FlarmTraffic *t) const noexcept {
     return t + 1 < list.end()
       ? t + 1
       : NULL;
@@ -177,14 +179,14 @@ struct TrafficList {
   /**
    * Search for the first traffic in the ordered list.
    */
-  const FlarmTraffic *FirstTraffic() const {
+  constexpr const FlarmTraffic *FirstTraffic() const noexcept {
     return list.empty() ? NULL : list.begin();
   }
 
   /**
    * Search for the last traffic in the ordered list.
    */
-  const FlarmTraffic *LastTraffic() const {
+  constexpr const FlarmTraffic *LastTraffic() const noexcept {
     return list.empty() ? NULL : list.end() - 1;
   }
 
@@ -192,9 +194,10 @@ struct TrafficList {
    * Finds the most critical alert.  Returns NULL if there is no
    * alert.
    */
-  const FlarmTraffic *FindMaximumAlert() const;
+  [[gnu::pure]]
+  const FlarmTraffic *FindMaximumAlert() const noexcept;
 
-  unsigned TrafficIndex(const FlarmTraffic *t) const {
+  constexpr unsigned TrafficIndex(const FlarmTraffic *t) const noexcept {
     return t - list.begin();
   }
 };
