@@ -46,22 +46,17 @@
 FlarmTrafficWindow::FlarmTrafficWindow(const FlarmTrafficLook &_look,
                                        unsigned _h_padding,
                                        unsigned _v_padding,
-                                       bool _small)
+                                       bool _small) noexcept
   :look(_look),
-   distance(2000),
-   selection(-1), warning(-1),
    h_padding(_h_padding), v_padding(_v_padding),
-   small(_small),
-   enable_north_up(false),
-   heading(Angle::Zero()),
-   side_display_type(SIDE_INFO_VARIO)
+   small(_small)
 {
   data.Clear();
   data_modified.Clear();
 }
 
 bool
-FlarmTrafficWindow::WarningMode() const
+FlarmTrafficWindow::WarningMode() const noexcept
 {
   assert(warning < (int)data.list.size());
   assert(warning < 0 || data.list[warning].IsDefined());
@@ -85,7 +80,7 @@ FlarmTrafficWindow::OnResize(PixelSize new_size)
 }
 
 void
-FlarmTrafficWindow::SetTarget(int i)
+FlarmTrafficWindow::SetTarget(int i) noexcept
 {
   assert(i < (int)data.list.size());
   assert(i < 0 || data.list[i].IsDefined());
@@ -101,7 +96,7 @@ FlarmTrafficWindow::SetTarget(int i)
  * Tries to select the next target, if impossible selection = -1
  */
 void
-FlarmTrafficWindow::NextTarget()
+FlarmTrafficWindow::NextTarget() noexcept
 {
   // If warning is displayed -> prevent selector movement
   if (WarningMode())
@@ -125,7 +120,7 @@ FlarmTrafficWindow::NextTarget()
  * Tries to select the previous target, if impossible selection = -1
  */
 void
-FlarmTrafficWindow::PrevTarget()
+FlarmTrafficWindow::PrevTarget() noexcept
 {
   // If warning is displayed -> prevent selector movement
   if (WarningMode())
@@ -150,7 +145,8 @@ FlarmTrafficWindow::PrevTarget()
  * to select the next one
  */
 void
-FlarmTrafficWindow::UpdateSelector(const FlarmId id, const PixelPoint pt)
+FlarmTrafficWindow::UpdateSelector(const FlarmId id,
+                                   const PixelPoint pt) noexcept
 {
   // Update #selection
   if (!id.IsDefined())
@@ -172,7 +168,7 @@ FlarmTrafficWindow::UpdateSelector(const FlarmId id, const PixelPoint pt)
  * alarm level and saves it to "warning".
  */
 void
-FlarmTrafficWindow::UpdateWarnings()
+FlarmTrafficWindow::UpdateWarnings() noexcept
 {
   const FlarmTraffic *alert = data.FindMaximumAlert();
   warning = alert != NULL
@@ -185,7 +181,7 @@ FlarmTrafficWindow::UpdateWarnings()
  */
 void
 FlarmTrafficWindow::Update(Angle new_direction, const TrafficList &new_data,
-                           const TeamCodeSettings &new_settings)
+                           const TeamCodeSettings &new_settings) noexcept
 {
   static constexpr Angle min_heading_delta = Angle::Degrees(2);
   if (new_data.modified == data_modified &&
@@ -222,7 +218,7 @@ FlarmTrafficWindow::Update(Angle new_direction, const TrafficList &new_data,
  * @param d Distance in meters to the own plane
  */
 double
-FlarmTrafficWindow::RangeScale(double d) const
+FlarmTrafficWindow::RangeScale(double d) const noexcept
 {
   d /= distance;
   return std::min(d, 1.) * radius;
@@ -233,7 +229,7 @@ FlarmTrafficWindow::RangeScale(double d) const
  * @param canvas The canvas to paint on
  */
 void
-FlarmTrafficWindow::PaintRadarNoTraffic(Canvas &canvas) const
+FlarmTrafficWindow::PaintRadarNoTraffic(Canvas &canvas) const noexcept
 {
   if (small)
     return;
@@ -245,9 +241,9 @@ FlarmTrafficWindow::PaintRadarNoTraffic(Canvas &canvas) const
   canvas.DrawText(radar_mid - PixelSize{ts.width / 2, radius / 2}, str);
 }
 
-gcc_const
+[[gnu::const]]
 static const Pen *
-FlarmColorPen(const FlarmTrafficLook &look, FlarmColor color)
+FlarmColorPen(const FlarmTrafficLook &look, FlarmColor color) noexcept
 {
   switch (color) {
   case FlarmColor::NONE:
@@ -280,7 +276,7 @@ FlarmColorPen(const FlarmTrafficLook &look, FlarmColor color)
 void
 FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
                                      const FlarmTraffic &traffic,
-                                     unsigned i)
+                                     unsigned i) noexcept
 {
   // Save relative East/North
   DoublePoint2D p(traffic.relative_east, -traffic.relative_north);
@@ -312,8 +308,7 @@ FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
 
   const Color *text_color;
   const Pen *target_pen, *circle_pen;
-  const Brush *target_brush, *arrow_brush;
-  bool hollow_brush = false;
+  const Brush *target_brush = nullptr, *arrow_brush;
   unsigned circles = 0;
 
   // Set the arrow color depending on alarm level
@@ -340,7 +335,6 @@ FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
       text_color = &look.passive_color;
       target_pen = &look.passive_pen;
       arrow_brush = &look.passive_brush;
-      hollow_brush = true;
     } else {
       // Search for team color
       const FlarmColor team_color = FlarmFriends::GetFriendColor(traffic.id);
@@ -359,7 +353,6 @@ FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
         target_brush = arrow_brush = &look.selection_brush;
         target_pen = &look.selection_pen;
       } else {
-        hollow_brush = true;
         if (traffic.IsPassive()) {
           text_color = &look.passive_color;
           target_pen = &look.passive_pen;
@@ -412,7 +405,7 @@ FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
 
   // Select pen and brush
   canvas.Select(*target_pen);
-  if (hollow_brush)
+  if (target_brush == nullptr)
     canvas.SelectHollowBrush();
   else
     canvas.Select(*target_brush);
@@ -432,7 +425,7 @@ FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
     return;
 
   // if vertical speed to small or negative -> skip this one
-  if (side_display_type == SIDE_INFO_VARIO &&
+  if (side_display_type == SideInfoType::VARIO &&
       (!traffic.climb_rate_avg30s_available ||
        traffic.climb_rate_avg30s < 0.5 ||
        traffic.IsPowered()))
@@ -445,7 +438,7 @@ FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
   // Format string
   TCHAR tmp[10];
 
-  if (side_display_type == SIDE_INFO_VARIO)
+  if (side_display_type == SideInfoType::VARIO)
     FormatUserVerticalSpeed(traffic.climb_rate_avg30s, tmp, false);
   else
     FormatRelativeUserAltitude(traffic.relative_altitude, tmp, true);
@@ -469,9 +462,11 @@ FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
 }
 
 void
-FlarmTrafficWindow::PaintTargetInfoSmall(
-    Canvas &canvas, const FlarmTraffic &traffic, unsigned i,
-    const Color &text_color, const Brush &arrow_brush)
+FlarmTrafficWindow::PaintTargetInfoSmall(Canvas &canvas,
+                                         const FlarmTraffic &traffic,
+                                         unsigned i,
+                                         const Color &text_color,
+                                         const Brush &arrow_brush) noexcept
 {
   const short relalt =
       iround(Units::ToUserAltitude(traffic.relative_altitude) / 100);
@@ -536,7 +531,7 @@ FlarmTrafficWindow::PaintTargetInfoSmall(
  * @param canvas The canvas to paint on
  */
 void
-FlarmTrafficWindow::PaintRadarTraffic(Canvas &canvas)
+FlarmTrafficWindow::PaintRadarTraffic(Canvas &canvas) noexcept
 {
   if (data.IsEmpty()) {
     PaintRadarNoTraffic(canvas);
@@ -576,7 +571,7 @@ FlarmTrafficWindow::PaintRadarTraffic(Canvas &canvas)
  * @param canvas The canvas to paint on
  */
 void
-FlarmTrafficWindow::PaintRadarPlane(Canvas &canvas) const
+FlarmTrafficWindow::PaintRadarPlane(Canvas &canvas) const noexcept
 {
   canvas.Select(look.plane_pen);
 
@@ -613,7 +608,7 @@ FlarmTrafficWindow::PaintRadarPlane(Canvas &canvas) const
   canvas.DrawLine(radar_mid + p1, radar_mid + p2);
 }
 
-gcc_const
+[[gnu::const]]
 static PixelPoint
 iround(DoublePoint2D p) noexcept
 {
@@ -625,7 +620,7 @@ iround(DoublePoint2D p) noexcept
  * @param canvas The canvas to paint on
  */
 void
-FlarmTrafficWindow::PaintNorth(Canvas &canvas) const
+FlarmTrafficWindow::PaintNorth(Canvas &canvas) const noexcept
 {
   DoublePoint2D p(0, -1);
   if (!enable_north_up) {
@@ -661,7 +656,7 @@ DrawCircleLabel(Canvas &canvas, PixelPoint p,
  * @param canvas The canvas to paint on
  */
 void
-FlarmTrafficWindow::PaintRadarBackground(Canvas &canvas) const
+FlarmTrafficWindow::PaintRadarBackground(Canvas &canvas) const noexcept
 {
   canvas.SelectHollowBrush();
   canvas.Select(look.radar_pen);
@@ -701,7 +696,7 @@ FlarmTrafficWindow::PaintRadarBackground(Canvas &canvas) const
  * @param canvas The canvas to paint on
  */
 void
-FlarmTrafficWindow::Paint(Canvas &canvas)
+FlarmTrafficWindow::Paint(Canvas &canvas) noexcept
 {
   assert(selection < (int)data.list.size());
   assert(selection < 0 || data.list[selection].IsDefined());
@@ -736,7 +731,7 @@ FlarmTrafficWindow::OnPaint(Canvas &canvas)
 }
 
 bool
-FlarmTrafficWindow::SelectNearTarget(PixelPoint p, int max_distance)
+FlarmTrafficWindow::SelectNearTarget(PixelPoint p, int max_distance) noexcept
 {
   int min_distance = 99999;
   int min_id = -1;
