@@ -746,11 +746,11 @@ InputEvents::eventExchangeFrequencies(const TCHAR *misc)
 void
 InputEvents::eventUploadIGCFile(const TCHAR *misc) {
   FileDataField df;
-  df.ScanMultiplePatterns(_T("*.igc"));
+  df.ScanMultiplePatterns(_T("*.igc\0"));
   df.SetFileType(FileType::IGC);
   if (FilePicker(_T("IGC-FilePicker"), df)) {
     auto path = df.GetValue();
-    if (!path.IsEmpty())
+    if (!path.empty())
       if (WeGlide::UploadIGCFile(path)) {
         // success!
       }
