@@ -2,7 +2,7 @@
   Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,17 +24,17 @@
 #ifndef THERMAL_ASSISTANT_WINDOW_LOOK_HPP
 #define THERMAL_ASSISTANT_WINDOW_LOOK_HPP
 
-#include "Screen/Color.hpp"
-#include "Screen/Pen.hpp"
-#include "Screen/Brush.hpp"
-#include "Screen/Font.hpp"
+#include "ui/canvas/Color.hpp"
+#include "ui/canvas/Pen.hpp"
+#include "ui/canvas/Brush.hpp"
+#include "ui/canvas/Font.hpp"
 
 struct ThermalAssistantLook {
-  Color background_color;
-  Color circle_color;
-  Color text_color;
-  Color polygon_fill_color;
-  Color polygon_border_color;
+  static constexpr Color background_color = COLOR_WHITE;
+  static constexpr Color circle_color{0xB0, 0xB0, 0xB0};
+  static constexpr Color text_color = COLOR_BLACK;
+  static constexpr Color polygon_fill_color{0xCC, 0xCC, 0xFF};
+  static constexpr Color polygon_border_color = COLOR_BLUE;
 
   Brush polygon_brush;
 
