@@ -36,6 +36,9 @@ struct WaypointLook {
   MaskedIcon mountain_top_icon, bridge_icon, obstacle_icon;
   MaskedIcon tower_icon, power_plant_icon, tunnel_icon, thermal_hotspot_icon;
   MaskedIcon marker_icon;
+  MaskedIcon vor_icon, ndb_icon, reporting_point_icon;
+  MaskedIcon dam_icon, castle_icon, intersection_icon;
+  MaskedIcon pgtakeoff_icon, pglanding_icon;
   MaskedIcon airport_reachable_icon, airport_unreachable_icon;
   MaskedIcon airport_marginal_icon;
   MaskedIcon field_marginal_icon, field_reachable_icon, field_unreachable_icon;
