@@ -25,6 +25,7 @@ Copyright_License {
 #include "Look/MapLook.hpp"
 #include "Geo/GeoClip.hpp"
 #include "Task/ProtectedRoutePlanner.hpp"
+#include "Route/FlatTriangleFanVisitor.hpp"
 
 #ifdef ENABLE_OPENGL
 #include "ui/canvas/opengl/Scope.hpp"
@@ -65,7 +66,7 @@ struct ProjectedFan {
       triangle_buffer[i] += start;
 
     glDrawElements(GL_TRIANGLES, idx_count, GL_UNSIGNED_SHORT,
-                   triangle_buffer.begin());
+                   triangle_buffer.data());
   }
 
   void DrawOutline(unsigned start) const {
@@ -83,7 +84,7 @@ struct ProjectedFan {
 };
 
 struct ProjectedFans {
-  typedef StaticArray<ProjectedFan, FlatTriangleFanTree::REACH_MAX_FANS> ProjectedFanVector;
+  typedef StaticArray<ProjectedFan, FlatTriangleFanTree::MAX_FANS> ProjectedFanVector;
 
   ProjectedFanVector fans;
 
@@ -104,7 +105,7 @@ struct ProjectedFans {
 #endif
   {
     /* try to guess the total number of vertices */
-    points.reserve(FlatTriangleFanTree::REACH_MAX_FANS * ROUTEPOLAR_POINTS / 10);
+    points.reserve(FlatTriangleFanTree::MAX_FANS * ROUTEPOLAR_POINTS / 10);
   }
 
   bool empty() const {
@@ -178,7 +179,7 @@ struct ProjectedFans {
   }
 };
 
-typedef StaticArray<ProjectedFan, FlatTriangleFanTree::REACH_MAX_FANS> ProjectedFanVector;
+typedef StaticArray<ProjectedFan, FlatTriangleFanTree::MAX_FANS> ProjectedFanVector;
 
 class TriangleCompound final : public FlatTriangleFanVisitor {
   /**
@@ -204,18 +205,18 @@ public:
 
   /* virtual methods from class FlatTriangleFanVisitor */
 
-  void VisitFan(FlatGeoPoint origin, ConstBuffer<FlatGeoPoint> fan) override {
+  void VisitFan(FlatGeoPoint origin, std::span<const FlatGeoPoint> fan) noexcept override {
 
-    if (fan.size < 3 || fans.full())
+    if (fan.size() < 3 || fans.full())
       return;
 
     GeoPoint g[ROUTEPOLAR_POINTS + 2];
-    for (size_t i = 0; i < fan.size; ++i)
+    for (size_t i = 0; i < fan.size(); ++i)
       g[i] = flat_projection.Unproject(fan[i]);
 
     // Perform clipping on the GeoPointVector
     GeoPoint clipped[(ROUTEPOLAR_POINTS + 2) * 3];
-    unsigned size = clip.ClipPolygon(clipped, g, fan.size);
+    unsigned size = clip.ClipPolygon(clipped, g, fan.size());
     // With less than three points we can't draw a polygon
     if (size < 3)
       return;
