@@ -120,7 +120,7 @@ MapWindow::DrawTaskOffTrackIndicator(Canvas &canvas)
   const GeoPoint target = current_leg.location_remaining;
   GeoVector vec(Basic().location, target);
 
-  if ((Basic().track - vec.bearing).AsDelta().AbsoluteDegrees() < 10)
+  if ((Basic().track - vec.bearing).AsDelta().Absolute() < Angle::Degrees(10))
     // insignificant error
     return;
 
