@@ -25,6 +25,8 @@ Copyright_License {
 #include "Look/MapLook.hpp"
 #include "ui/canvas/Icon.hpp"
 #include "Tracking/SkyLines/Data.hpp"
+#include "net/client/tim/Glue.hpp"
+#include "net/client/tim/Thermal.hpp"
 
 template<typename T>
 static void
@@ -76,4 +78,9 @@ MapWindow::DrawThermalEstimate(Canvas &canvas) const
         look.thermal_source_icon.Draw(canvas, *p);
     }
   }
+
+  if (tim_glue != nullptr && ComputerSettings().weather.enable_tim)
+    for (const auto &i : tim_glue->Get())
+      if (auto p = render_projection.GeoToScreenIfVisible(i.location))
+        look.thermal_source_icon.Draw(canvas, *p);
 }
