@@ -35,6 +35,10 @@ sin_cos(const double thetha) noexcept
   double s, c;
 #ifdef __APPLE__
   __sincos(thetha, &s, &c);
+#elif defined(_MSC_VER)
+  // STL and MSVC have no sincos...
+  s = sin(thetha);
+  c = cos(thetha);
 #else
   sincos(thetha, &s, &c);
 #endif
