@@ -37,13 +37,6 @@ Copyright_License {
 #include "Airspace/ProtectedAirspaceWarningManager.hpp"
 #include "Formatter/TimeFormatter.hpp"
 
-#if defined(__GNUC__) && !defined(__clang__)
-/* this warning is bogus because GCC is not clever enough to
-   understand that the "state" variable in Check() only gets evaluated
-   if it has been initialised */
-#pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
-#endif
-
 class AirspaceWarningWidget final
   : public QuestionWidget {
 
@@ -58,7 +51,7 @@ class AirspaceWarningWidget final
   gcc_pure
   const TCHAR *MakeMessage(const AbstractAirspace &airspace,
                            AirspaceWarning::State state,
-                           const AirspaceInterceptSolution &solution) {
+                           const AirspaceInterceptSolution &solution) noexcept {
     if (state == AirspaceWarning::WARNING_INSIDE)
       buffer.Format(_T("%s: %s"), _("Inside airspace"), airspace.GetName());
     else
@@ -74,7 +67,7 @@ public:
                         ProtectedAirspaceWarningManager &_manager,
                         ConstAirspacePtr _airspace,
                         AirspaceWarning::State _state,
-                        const AirspaceInterceptSolution &solution)
+                        const AirspaceInterceptSolution &solution) noexcept
     :QuestionWidget(MakeMessage(*_airspace, _state, solution)),
      monitor(_monitor), manager(_manager),
      airspace(std::move(_airspace)), state(_state) {
@@ -98,14 +91,14 @@ public:
     });
   }
 
-  ~AirspaceWarningWidget() {
+  ~AirspaceWarningWidget() noexcept {
     assert(monitor.widget == this);
     monitor.widget = nullptr;
   }
 
   bool Update(const AbstractAirspace &_airspace,
               AirspaceWarning::State _state,
-              const AirspaceInterceptSolution &solution) {
+              const AirspaceInterceptSolution &solution) noexcept {
     if (&_airspace != airspace.get())
       return false;
 
@@ -116,7 +109,7 @@ public:
 };
 
 void
-AirspaceWarningMonitor::Reset()
+AirspaceWarningMonitor::Reset() noexcept
 {
   const auto &calculated = CommonInterface::Calculated();
 
@@ -124,7 +117,7 @@ AirspaceWarningMonitor::Reset()
 }
 
 void
-AirspaceWarningMonitor::HideWidget()
+AirspaceWarningMonitor::HideWidget() noexcept
 {
   if (widget != nullptr)
     PageActions::RestoreBottom();
@@ -132,7 +125,7 @@ AirspaceWarningMonitor::HideWidget()
 }
 
 void
-AirspaceWarningMonitor::Check()
+AirspaceWarningMonitor::Check() noexcept
 {
   const auto &calculated = CommonInterface::Calculated();
 
@@ -166,21 +159,9 @@ AirspaceWarningMonitor::Check()
     return;
   }
 
-  ConstAirspacePtr airspace;
-  AirspaceWarning::State state;
-  AirspaceInterceptSolution solution;
+  const auto w = airspace_warnings->GetTopWarning();
 
-  {
-    const ProtectedAirspaceWarningManager::Lease lease(*airspace_warnings);
-    auto w = lease->begin();
-    if (w != lease->end() && w->IsAckExpired()) {
-      airspace = w->GetAirspacePtr();
-      state = w->GetWarningState();
-      solution = w->GetSolution();
-    }
-  }
-
-  if (airspace == nullptr) {
+  if (!w || !w->IsActive()) {
     HideWidget();
     return;
   }
@@ -188,14 +169,17 @@ AirspaceWarningMonitor::Check()
   if (CommonInterface::GetUISettings().enable_airspace_warning_dialog) {
     /* show airspace warning */
     if (widget != nullptr) {
-      if (widget->Update(*airspace, state, solution))
+      if (widget->Update(w->GetAirspace(), w->GetWarningState(),
+                         w->GetSolution()))
         return;
 
       HideWidget();
     }
 
     widget = new AirspaceWarningWidget(*this, *airspace_warnings,
-                                       std::move(airspace), state, solution);
+                                       w->GetAirspacePtr(),
+                                       w->GetWarningState(),
+                                       w->GetSolution());
     PageActions::SetCustomBottom(widget);
   }
 
