@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -32,12 +32,13 @@ Copyright_License {
  */
 class NoCancelOperationEnvironment : public ProxyOperationEnvironment {
 public:
-  NoCancelOperationEnvironment(OperationEnvironment &_other)
+  NoCancelOperationEnvironment(OperationEnvironment &_other) noexcept
     :ProxyOperationEnvironment(_other) {}
 
   /* virtual methods from class OperationEnvironment */
-  bool IsCancelled() const override;
-  void Sleep(unsigned ms) override;
+  bool IsCancelled() const noexcept override;
+  void SetCancelHandler(std::function<void()> handler) noexcept override;
+  void Sleep(std::chrono::steady_clock::duration duration) noexcept override;
 };
 
 #endif
