@@ -24,7 +24,7 @@ Copyright_License {
 #ifndef XCSOAR_RESOURCE_LOADER_HPP
 #define XCSOAR_RESOURCE_LOADER_HPP
 
-#include "util/ConstBuffer.hxx"
+#include <span>
 
 #ifdef _WIN32
 #include <windef.h>
@@ -35,25 +35,27 @@ Copyright_License {
 class ResourceId;
 
 namespace ResourceLoader {
+
 #ifdef _WIN32
-  void
-  Init(HINSTANCE hInstance);
+void
+Init(HINSTANCE hInstance);
 #endif
 
-  typedef ConstBuffer<void> Data;
+using Data = std::span<const std::byte>;
 
-  Data
-  Load(const TCHAR *name, const TCHAR *type);
+Data
+Load(const TCHAR *name, const TCHAR *type);
 
 #ifndef ANDROID
-  Data
-  Load(ResourceId id);
+Data
+Load(ResourceId id);
 #endif
 
 #ifdef _WIN32
-  HBITMAP
-  LoadBitmap2(ResourceId id);
+HBITMAP
+LoadBitmap2(ResourceId id);
 #endif
-}
+
+} // namespace ResourceLoader
 
 #endif
