@@ -23,8 +23,8 @@ Copyright_License {
 
 #include "Screen/Layout.hpp"
 #include "ui/dim/Size.hpp"
+#include "ui/display/Display.hpp"
 #include "Hardware/DisplayDPI.hpp"
-#include "Hardware/DisplaySize.hpp"
 #include "Asset.hpp"
 
 #include <algorithm>
@@ -70,14 +70,25 @@ IsSmallScreen(unsigned width, unsigned height,
  * Is the small edge smaller than 5 inch?
  */
 static constexpr bool
-IsSmallScreen(PixelSize size,
-              unsigned x_dpi, unsigned y_dpi) noexcept
+IsSmallScreen(PixelSize size, UnsignedPoint2D dpi) noexcept
 {
-  return IsSmallScreen(size.width, size.height, x_dpi, y_dpi);
+  return IsSmallScreen(size.width, size.height, dpi.x, dpi.y);
+}
+
+[[gnu::pure]]
+static PixelSize
+GetDisplaySize(const UI::Display &display, PixelSize fallback) noexcept
+{
+#if defined(USE_X11) || defined(USE_GDI)
+  return display.GetSize();
+#else
+  return fallback;
+#endif
 }
 
 void
-Layout::Initialize(PixelSize new_size, unsigned ui_scale, unsigned custom_dpi) noexcept
+Layout::Initialise(const UI::Display &display, PixelSize new_size,
+                   unsigned ui_scale, unsigned custom_dpi) noexcept
 {
   const unsigned width = new_size.width, height = new_size.height;
 
@@ -88,20 +99,19 @@ Layout::Initialize(PixelSize new_size, unsigned ui_scale, unsigned custom_dpi) n
   if (!ScaleSupported())
     return;
 
-  const unsigned x_dpi = Display::GetXDPI(custom_dpi);
-  const unsigned y_dpi = Display::GetYDPI(custom_dpi);
-  const bool is_small_screen = IsSmallScreen(Display::GetSize(new_size),
-                                             x_dpi, y_dpi);
+  const auto dpi = Display::GetDPI(display, custom_dpi);
+  const bool is_small_screen = IsSmallScreen(GetDisplaySize(display, new_size),
+                                             dpi);
 
   // always start w/ shortest dimension
   // square should be shrunk
   scale_1024 = std::max(1024U, min_screen_pixels * 1024 / (square ? 320 : 240));
   scale = scale_1024 / 1024;
 
-  pen_width_scale = std::max(1024u, x_dpi * 1024u / 80u);
-  fine_pen_width_scale = std::max(1024u, x_dpi * 1024u / 160u);
+  pen_width_scale = std::max(1024u, dpi.x * 1024u / 80u);
+  fine_pen_width_scale = std::max(1024u, dpi.x * 1024u / 160u);
 
-  pt_scale = 1024 * y_dpi / 72;
+  pt_scale = 1024 * dpi.y / 72;
 
   vpt_scale = pt_scale;
   if (is_small_screen)
@@ -109,7 +119,7 @@ Layout::Initialize(PixelSize new_size, unsigned ui_scale, unsigned custom_dpi) n
        the viewing distance is usually smaller */
     vpt_scale = vpt_scale * 2 / 3;
 
-  font_scale = 1024 * y_dpi * ui_scale / 72 / 100;
+  font_scale = 1024 * dpi.y * ui_scale / 72 / 100;
   if (is_small_screen)
     /* small screens (on portable devices) use a smaller font because
        the viewing distance is usually smaller */
