@@ -33,15 +33,15 @@ Copyright_License {
 struct RasterLocation : UnsignedPoint2D {
   using UnsignedPoint2D::UnsignedPoint2D;
 
-  constexpr RasterLocation operator>>(unsigned bits) const {
+  constexpr RasterLocation operator>>(unsigned bits) const noexcept {
     return RasterLocation(x >> bits, y >> bits);
   }
 
-  constexpr RasterLocation operator<<(unsigned bits) const {
+  constexpr RasterLocation operator<<(unsigned bits) const noexcept {
     return RasterLocation(x << bits, y << bits);
   }
 
-  constexpr RasterLocation RoundingRightShift(unsigned bits) const {
+  constexpr RasterLocation RoundingRightShift(unsigned bits) const noexcept {
     return RasterLocation(::RoundingRightShift(x, bits),
                           ::RoundingRightShift(y, bits));
   }
@@ -50,22 +50,22 @@ struct RasterLocation : UnsignedPoint2D {
 struct SignedRasterLocation : IntPoint2D {
   using IntPoint2D::IntPoint2D;
 
-  constexpr SignedRasterLocation(RasterLocation other)
+  constexpr SignedRasterLocation(RasterLocation other) noexcept
     :IntPoint2D(other.x, other.y) {}
 
-  constexpr operator RasterLocation() const {
+  constexpr operator RasterLocation() const noexcept {
     return RasterLocation(x, y);
   }
 
-  constexpr SignedRasterLocation operator>>(int bits) const {
+  constexpr SignedRasterLocation operator>>(int bits) const noexcept {
     return SignedRasterLocation(x >> bits, y >> bits);
   }
 
-  constexpr SignedRasterLocation operator<<(int bits) const {
+  constexpr SignedRasterLocation operator<<(int bits) const noexcept {
     return SignedRasterLocation(x << bits, y << bits);
   }
 
-  constexpr SignedRasterLocation RoundingRightShift(unsigned bits) const {
+  constexpr SignedRasterLocation RoundingRightShift(unsigned bits) const noexcept {
     return SignedRasterLocation(::RoundingRightShift(x, bits),
                                 ::RoundingRightShift(y, bits));
   }
