@@ -246,7 +246,7 @@ TopographyFileRenderer::Paint(Canvas &canvas,
             offset += n;
           }
         } else {
-          for (unsigned n : ConstBuffer<GLushort>(indices.count, lines.size)) {
+          for (unsigned n : std::span<const GLushort>{indices.count, lines.size()}) {
             glDrawElements(GL_LINE_STRIP, n, GL_UNSIGNED_SHORT,
                            indices.indices);
             indices.indices += n;
@@ -307,8 +307,8 @@ TopographyFileRenderer::Paint(Canvas &canvas,
           for (unsigned i = 0; i < msize; ++i)
             geo_points[i] = src[i * iskip];
 
-          msize = clip.ClipPolygon(geo_points.begin(),
-                                   geo_points.begin(), msize);
+          msize = clip.ClipPolygon(geo_points.data(),
+                                   geo_points.data(), msize);
           if (msize < 3)
             continue;
 
