@@ -25,8 +25,8 @@ Copyright_License {
 #include "Operation/Operation.hpp"
 #include "util/StringCompare.hxx"
 #include "util/ConvertString.hpp"
-#include "net/http/CoRequest.hxx"
-#include "net/http/Setup.hxx"
+#include "lib/curl/CoRequest.hxx"
+#include "lib/curl/Setup.hxx"
 #include "Geo/GeoPoint.hpp"
 #include "co/Task.hxx"
 #include "util/RuntimeError.hxx"
