@@ -155,8 +155,17 @@ ButtonPanelWidget::SetFocus() noexcept
   return widget->SetFocus();
 }
 
+bool
+ButtonPanelWidget::HasFocus() const noexcept
+{
+  return widget->HasFocus() || buttons->HasFocus();
+}
+
 bool
 ButtonPanelWidget::KeyPress(unsigned key_code) noexcept
 {
-  return buttons->KeyPress(key_code) || widget->KeyPress(key_code);
+  /* apply ButtonPanel hot keys and cursor navigation only any part of
+     this widget is focused */
+  return (HasFocus() && buttons->KeyPress(key_code)) ||
+    widget->KeyPress(key_code);
 }
