@@ -22,13 +22,13 @@ Copyright_License {
 */
 
 #include "CoDownloadToFile.hpp"
-#include "Setup.hxx"
 #include "Progress.hpp"
-#include "CoStreamRequest.hxx"
+#include "lib/curl/Setup.hxx"
+#include "lib/curl/CoStreamRequest.hxx"
+#include "io/DigestOutputStream.hxx"
 #include "io/FileOutputStream.hxx"
 #include "system/Path.hpp"
-#include "Crypto/SHA256.hxx"
-#include "Crypto/DigestOutputStream.hxx"
+#include "lib/sodium/SHA256.hxx"
 
 #include <cassert>
 #include <optional>
