@@ -24,11 +24,9 @@ Copyright_License {
 #ifndef XCSOAR_SCREEN_OPENGL_EXTENSION_HPP
 #define XCSOAR_SCREEN_OPENGL_EXTENSION_HPP
 
-#include "util/Compiler.h"
-
 namespace OpenGL {
 
-gcc_pure
+[[gnu::pure]]
 bool
 IsExtensionSupported(const char *name) noexcept;
 
