@@ -46,6 +46,9 @@ class EventQueue {
 public:
   EventQueue() noexcept;
 
+  void Suspend() noexcept {}
+  void Resume() noexcept {}
+
   /**
    * Caching wrapper for std::chrono::steady_clock::now().  The
    * real clock is queried at most once per event loop
